@@ -13,7 +13,7 @@ from ._cli_mixin import CliMixin
 from ._cli_mixin import LazyVersionStr
 from ._components import AllComponents
 
-__all__ = ["aux", "hello"]
+__all__ = ["adaux", "hello"]
 
 
 def hello(bla: str, param: tp.Optional[click.Parameter] = None) -> str:
@@ -38,6 +38,13 @@ class _ClickPrintMixin:
 @click.version_option(version=LazyVersionStr())  # type: ignore
 @click.pass_context
 @click.option("--target", "-t", type=Path, help="Location of the repository.")
+@click.option(
+    "--bake-before",
+    "-b",
+    is_flag=True,
+    default=False,
+    help="Bake before executing the command.",
+)
 @click.option(
     "--silent",
     "-s",
@@ -45,7 +52,9 @@ class _ClickPrintMixin:
     default=False,
     help="Suppress any output on success.",
 )
-def aux(ctx: click.Context, target: tp.Optional[Path], silent: bool) -> None:
+def adaux(
+    ctx: click.Context, target: tp.Optional[Path], bake_before: bool, silent: bool
+) -> None:
 
     ctx.color = os.environ.get("NO_COLOR", "") == ""
     cls = AllComponents.compose(CliMixin, _ClickPrintMixin)
@@ -55,11 +64,13 @@ def aux(ctx: click.Context, target: tp.Optional[Path], silent: bool) -> None:
 
     if ctx.obj.auxcon_file.exists():
         raise_if_init_and_not_force(ctx)
+        if bake_before:
+            ctx.invoke(bake)
     else:
         raise_if_not_init(ctx)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 def demo(ctx: click.Context) -> None:
     r"""
@@ -68,7 +79,7 @@ def demo(ctx: click.Context) -> None:
     ctx.obj.demo()
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.option(
     "-a", "--full", is_flag=True, default=False, help="display all extra settings"
@@ -80,7 +91,7 @@ def show(ctx: click.Context, full: bool) -> None:
     ctx.obj.show(full)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.option("-f", "--force", is_flag=True, default=False)
 @click.option(
@@ -108,9 +119,9 @@ def init(
         ctx.obj.init(project_name, project_slug, python_version, author, force=force)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
-@click.option("--bake_after", "-b", is_flag=True, default=False)
+@click.option("--bake_after", "-b", is_flag=True)
 def sync(ctx: click.Context, bake_after: bool) -> None:
     r"""
     Synchronizes local auxilium file with potentially newer template.
@@ -123,7 +134,7 @@ def sync(ctx: click.Context, bake_after: bool) -> None:
         ctx.obj.bake()
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 def bake(ctx: click.Context) -> None:  # pylint: disable=too-many-statements
     """
@@ -133,7 +144,7 @@ def bake(ctx: click.Context) -> None:  # pylint: disable=too-many-statements
         ctx.obj.bake()
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.argument("auxcon_file")
 def pre_commit_bake(ctx: click.Context, auxcon_file: str) -> None:
@@ -150,7 +161,7 @@ gitlab_token_option = click.option(
 )
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @gitlab_token_option
 def gitlab(ctx: click.Context, token: str) -> None:
@@ -162,7 +173,7 @@ def gitlab(ctx: click.Context, token: str) -> None:
         ctx.obj.gitlab(token)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @gitlab_token_option
 @click.option(
@@ -192,7 +203,7 @@ def pipeline(ctx: click.Context, token: str, watch: bool, show_success: bool) ->
             time.sleep(30)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.option(
     "-M",
@@ -226,7 +237,7 @@ def tick(
         ctx.obj.tick(" ".join(release_message), major, minor, commit)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @gitlab_token_option
 @click.option(
@@ -274,7 +285,7 @@ def release(
             time.sleep(30)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.option("-f", "--force", is_flag=True, default=False)
 @click.argument("src", type=click.Path(exists=True), default=Path("auxilium.cfg"))
@@ -289,7 +300,7 @@ def convert(ctx: click.Context, src: Path, dest: Path, force: bool) -> None:
 
 
 def fwd_all_inputs(fct: tp.Any) -> tp.Any:
-    return aux.command(context_settings={"ignore_unknown_options": True})(
+    return adaux.command(context_settings={"ignore_unknown_options": True})(
         click.pass_context(click.argument("args", nargs=-1)(fct))
     )
 
@@ -303,7 +314,7 @@ def ci(ctx: click.Context, args: tp.List[str]) -> None:
         ctx.obj.ci(*args)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.option("-h", "--open-html", is_flag=True, default=False)
 def cov(ctx: click.Context, open_html: bool) -> None:
@@ -323,7 +334,19 @@ def dcp(ctx: click.Context, args: tp.List[str]) -> None:
         ctx.obj.dcp(*args)
 
 
-@aux.command()
+@adaux.command(context_settings={"ignore_unknown_options": True})
+@click.pass_context
+@click.argument("composition")
+@click.argument("args", nargs=-1)
+def comp(ctx: click.Context, composition: str, args: tp.List[str]) -> None:
+    """
+    Shortcut for specific compositions shell file: x-compose.sh
+    """
+    with convert_runtime_to_click_error():
+        ctx.obj.comp(composition, *args)
+
+
+@adaux.command()
 @click.pass_context
 @click.option("-h", "--open-html", is_flag=True, default=False)
 def docs(ctx: click.Context, open_html: bool) -> None:
@@ -370,7 +393,7 @@ def pra(ctx: click.Context, args: tp.List[str]) -> None:
         ctx.obj.pra(*args)
 
 
-@aux.command()
+@adaux.command()
 @click.pass_context
 @click.option("-z", "--zipped", is_flag=True, default=False)
 def sdist(ctx: click.Context, zipped: bool) -> None:
