@@ -30,23 +30,6 @@ class ExecutablesMixin(DependencyMixin, ProjectMixin):
         config = self.auxcon.project.config
         data = self.auxcon.executables
 
-        default_scripts = [
-            ("mypy", "mp"),
-            ("pylint", "pl"),
-            ("coverage", "cov"),
-            ("docker", "dcp"),
-            ("ci", "ci"),
-            ("pre-commit", "pra2"),
-            ("project", "pipi"),
-            ("package", "sdist"),
-            ("docs", "docs"),
-        ]
-
-        for key, val in default_scripts:
-            if self.is_enabled(key):
-                self.bake_file(f"scripts/{val}")
-                data.scripts += [f"devops/scripts/{val}"]
-
         config.options.scripts = data.scripts
         cscr = data.console_scripts
         for i, val in enumerate(cscr):
